@@ -10,7 +10,7 @@
 
 closedN <- function (object, estimator = NULL, level = 0.95, maxN = 1e7, dmax = 10) {
     if (!inherits(object, 'capthist'))
-        stop ('require capthist object')
+        stop ("requires 'capthist' object")
     if (inherits(object, 'list'))
         lapply(object, closedN, estimator=estimator, level=level, maxN=maxN)
     else {
