@@ -2,7 +2,7 @@
 ## package 'secr'
 ## confint.secr.R
 ## last changed 2009 06 11, 2009 07 16 2009 10 20
-## could be sped up by adopting Venzon & Moolgavkar algorithm e.g. in Bhat package 
+## could be sped up by adopting Venzon & Moolgavkar algorithm e.g. in Bhat package
 
 ############################################################################################
 
@@ -24,7 +24,7 @@ confint.secr <- function (object, parm, level = 0.95, newdata = NULL, tracelevel
     profileInterval <- function (parm, ...) {
 
         predicted <- function (beta) {
-            temp <- secr.lpredictor (newdata = newdata, model = object$model[[parm]], 
+            temp <- secr.lpredictor (newdata = newdata, model = object$model[[parm]],
                 indx = object$parindx[[parm]], beta = beta)[1,'estimate']
             untransform(temp, object$link[[parm]])
         }
@@ -44,18 +44,18 @@ confint.secr <- function (object, parm, level = 0.95, newdata = NULL, tracelevel
                     mask       = object$mask,
                     CL         = object$CL,
                     detectfn   = object$detectfn,
-                    designD    = D.designmatrix,  
+                    designD    = D.designmatrix,
                     design     = object$design,
                     design0    = object$design0,
                     groups     = object$groups,
                     details    = details,
                     logmult    = logmult,
                     betaw      = max(max(nchar(object$betanames)),8))
-                templl - gamma * predicted (beta2)   
+                templl - gamma * predicted (beta2)
             }
 
             ## maximize for fixed gamma (equivalent to fixed 'parm')
-            lagrange.fit <- nlm (p = object$fit$par, f = lagrange, gamma = gamma, hessian = FALSE)  
+            lagrange.fit <- nlm (p = object$fit$par, f = lagrange, gamma = gamma, hessian = FALSE)
             .localstuff$beta <- lagrange.fit$estimate
             lp <- - secr.loglikfn (
                 beta       = lagrange.fit$estimate,
@@ -66,14 +66,14 @@ confint.secr <- function (object, parm, level = 0.95, newdata = NULL, tracelevel
                 mask       = object$mask,
                 CL         = object$CL,
                 detectfn   = object$detectfn,
-                designD    = D.designmatrix,  
+                designD    = D.designmatrix,
                 design     = object$design,
                 design0    = object$design0,
                 groups     = object$groups,
                 details    = details,
                 logmult    = logmult,
                 betaw      = max(max(nchar(object$betanames)),8))
-            ## cat ('gamma ', gamma, '  coef ', lagrange.fit$estimate, '  lp ', lp, 
+            ## cat ('gamma ', gamma, '  coef ', lagrange.fit$estimate, '  lp ', lp,
             ##     '  lp - targetLL ', lp-targetLL, '\n')
             lp - targetLL
         }
@@ -87,13 +87,13 @@ confint.secr <- function (object, parm, level = 0.95, newdata = NULL, tracelevel
             if (is.null(fb)) fb <- rep(NA, np)
             fb[parm] <- x
             details$fixedbeta <- fb
-            fit <- secr.fit (capthist = object$capthist, mask = object$mask, 
-                buffer = object$buffer, CL = object$CL, detectfn = object$detectfn,   
-                start = object$start, 
-                link = object$link, fixed = object$fixed,  model = object$model, 
-                timecov = object$timecov, sessioncov = object$sessioncov, 
-                groups = object$groups, dframe = object$dframe, 
-                details = details, verify = FALSE, ...)$fit 
+            fit <- secr.fit (capthist = object$capthist, mask = object$mask,
+                buffer = object$buffer, CL = object$CL, detectfn = object$detectfn,
+                start = object$start,
+                link = object$link, fixed = object$fixed,  model = object$model,
+                timecov = object$timecov, sessioncov = object$sessioncov,
+                groups = object$groups, dframe = object$dframe,
+                details = details, verify = FALSE, ...)$fit
             - fit$value - targetLL
         }
 
@@ -102,8 +102,8 @@ confint.secr <- function (object, parm, level = 0.95, newdata = NULL, tracelevel
             OK <- FALSE
             bound.0 <- start
             f.0 <- profileLL (start, parm)
-            for (i in trialvals) { 
-               bound.1 <- start + step * i 
+            for (i in trialvals) {
+               bound.1 <- start + step * i
                f.1 <- profileLL (bound.1, parm)
                if (prod(sign(c(f.0, f.1)))<0) {  ## different
                    OK <- TRUE
@@ -112,7 +112,7 @@ confint.secr <- function (object, parm, level = 0.95, newdata = NULL, tracelevel
                else {
                    bound.0 <- bound.1
                    f.0 <- f.1
-               }                
+               }
             }
             if (!OK) {
                 if (is.character(parm))
@@ -127,10 +127,10 @@ confint.secr <- function (object, parm, level = 0.95, newdata = NULL, tracelevel
         }
 
         #######################
-        
-        if (is.numeric(parm)) 
+
+        if (is.numeric(parm))
             profileLL <- profileLL3
-        else 
+        else
             profileLL <- profileLL.lagrange
 
         estimate <- coef(object, alpha=1-level)[parm,]
@@ -142,9 +142,9 @@ confint.secr <- function (object, parm, level = 0.95, newdata = NULL, tracelevel
         else {
             startlow <- getlimit (0, -1, c(2,5,40,200,1000))
             startupp <- getlimit (0, +1, c(2,5,40,200,1000))
-        } 
+        }
 
-        temproot <- uniroot (profileLL, 
+        temproot <- uniroot (profileLL,
             parm    = parm,
             lower   = startlow['lower'],
             upper   = startlow['upper'],
@@ -152,12 +152,12 @@ confint.secr <- function (object, parm, level = 0.95, newdata = NULL, tracelevel
             f.upper = startlow['f.upper'],
             tol     = tol)
 
-        if (is.numeric(parm))  
+        if (is.numeric(parm))
             LCL <- temproot$root
-        else 
+        else
             LCL <- predicted (.localstuff$beta)
 
-        temproot <- uniroot (profileLL, 
+        temproot <- uniroot (profileLL,
             parm    = parm,
             lower   = startupp['lower'],
             upper   = startupp['upper'],
@@ -165,9 +165,9 @@ confint.secr <- function (object, parm, level = 0.95, newdata = NULL, tracelevel
             f.upper = startupp['f.upper'],
             tol     = tol)
 
-        if (is.numeric(parm))  
+        if (is.numeric(parm))
             UCL <- temproot$root
-        else 
+        else
             UCL <- predicted (.localstuff$beta)
 
         c(LCL, UCL)
@@ -177,7 +177,7 @@ confint.secr <- function (object, parm, level = 0.95, newdata = NULL, tracelevel
 
     memo ('Profile likelihood interval(s)...', tracelevel > 0)
 
-    if (!inherits(object, 'secr')) stop ('Requires secr object')
+    if (!inherits(object, 'secr')) stop ("requires 'secr' object")
     np <- length(object$betanames)  ## number of beta parameters
 
     ## case 1 - real parameter not 1:1 beta so require lagrange
@@ -186,7 +186,7 @@ confint.secr <- function (object, parm, level = 0.95, newdata = NULL, tracelevel
 
     if (is.character(parm)) {
         OK <- (parm %in% object$realnames)
-        if (any(!OK)) 
+        if (any(!OK))
             stop ('requested parameter(s) not in model')
         case <- ifelse (object$model[parm] != ~1, 1, 2)
         if (any(case==1)) {
@@ -202,15 +202,15 @@ confint.secr <- function (object, parm, level = 0.95, newdata = NULL, tracelevel
             }
             else {
                 grps  <- group.levels(object$capthist, object$groups)
-                temp <- D.designdata( object$mask, object$model$D, grps, 
+                temp <- D.designdata( object$mask, object$model$D, grps,
                     session(object$capthist), object$sessioncov)
-                D.designmatrix <- model.matrix(object$model$D, temp) 
+                D.designmatrix <- model.matrix(object$model$D, temp)
                 attr(D.designmatrix, 'dimD') <- attr(temp, 'dimD')
             }
         }
     }
-    else { 
-        if (any ((parm<1) | (parm>np))) 
+    else {
+        if (any ((parm<1) | (parm>np)))
             stop ('invalid beta parameter number')
         case <- rep(3, np)
     }
@@ -222,11 +222,11 @@ confint.secr <- function (object, parm, level = 0.95, newdata = NULL, tracelevel
     out <- matrix(nr=length(parm), nc=2)
 
     for (i in 1:length(parm)) {
-        parmn <- ifelse (case[i] == 2, match(parm[i], object$betanames), parm[i])        
+        parmn <- ifelse (case[i] == 2, match(parm[i], object$betanames), parm[i])
         out[i,] <- profileInterval(parmn)   ## character value if 'real'
         if (case[i] == 2) out[i,] <- untransform(out[i,], object$link[[parm[i]]])
     }
-    if (case == 3) 
+    if (case == 3)
         dimnames(out) <- list(object$betanames[parm], c('beta.lcl', 'beta.ucl'))
     else
         dimnames(out) <- list(parm, c('lcl', 'ucl'))
