@@ -67,11 +67,15 @@ derived <- function (object, sessnum = NULL, groups=NULL, alpha=0.05, se.esa = F
                 CLesa  <- esagradient (object, selection, asess)
                 sqrt(CLesa %*% object$beta.vcv %*% CLesa)
             }
+            weighted.mean <- function (a) {
+                ## allows for varying a 2010-11-30
+                length(a) / sum(1/a)
+            }
 
             getderived <- function (selection) {
                     if (is.null(sessnum)) sessnum <- 1
                     selected.a <- esa(object, sessnum)[selection]
-                    derivedmean <- c(mean(selected.a), sum(1/selected.a) )
+                    derivedmean <- c(weighted.mean(selected.a), sum(1/selected.a) )
                     derivedSE <- c(NA, NA)
                     varcomp1 <- c(NA, NA)
                     varcomp2 <- c(NA, NA)
