@@ -29,7 +29,7 @@ make.tri <- function (nx=10, ny=12, spacing = 20, detector='multi', binomN=0, or
 # see make.grid for binomN
 {
     if (!( detector %in% .localstuff$validdetectors ))
-        stop ('invalid detector type')
+        stop ("invalid detector type")
     dy2 <- spacing * cos (pi / 6)
     xvals <- seq(from = originxy[1], length = nx, by = spacing)
     yvals <- seq(from = originxy[2], length = ny, by = dy2)
@@ -80,7 +80,7 @@ ringID <- function (hextraps) {
     angle <- apply(hextraps, 1, radians)
     ring <- trunc(d / attr(hextraps, 'spacing') + 0.5) + 1
     if (max(ring)>26)
-        stop ('limited to 26 rings')
+        stop ("limited to 26 rings")
     ringorder <- order(ring, angle)
     hextraps[,] <- hextraps[ringorder,]
     ring <- ring[ringorder]
@@ -94,11 +94,11 @@ clip.hex <- function (traps, side = 20, centre = c(50, 60*cos(pi/6)),
     fuzz = 1e-3, ID = 'num', ...) {
     hex <- hexagon(side+fuzz, centre)
     hex <- matrix(unlist(hex), nc = 2)
-    OK <- apply(traps, 1, insidepoly, poly = hex)
+    OK <- insidepoly(traps, hex)
     temp <- subset(traps, OK, ...)
     if (!is.null(ID)) {
         if (!(ID %in% c('num', 'alpha')))
-            stop ('ID must be num or alpha')
+            stop (paste("ID must be", dQuote("num"), "or", dQuote("alpha")))
         if (ID == 'num') row.names(temp) <- 1:nrow(temp)
         if (ID == 'alpha') temp <- ringID(temp)
     }
