@@ -2,13 +2,53 @@
 ## package 'secr'
 ## mask.check.R
 ## Evaluate alternative mask buffer width and spacing
-## 2010 10 15, 2010-10-17, 2010-10-18, 2010-10-20
+## 2010 10 15, 2010-10-17, 2010-10-18, 2010-10-20, 2010-10-31
 ############################################################################################
 
-mindistfromedge <- function (mask, traps) {
-    bbox <- attr(mask,'boundingbox')
-    min (c( min(abs(outer(traps$x, bbox$x, '-'))),
-            min(abs(outer(traps$y, bbox$y, '-')))))
+bisect <- function(f, a, b, tol = 1e-6) {
+    x1 <- a
+    x2 <- b
+    f1 <- f(x1)
+    f2 <- f(x2)
+    while(abs(b - a) > tol) {
+       if(f1==f2) {
+        b <- x2
+        x2 <- x1
+        f2 <- f1
+        x1 <- b - 0.5 * (b - a)
+        f1 <- f(x1)
+      } else {
+        a <- x1
+        x1 <- x2
+        f1 <- f2
+        x2 <- a + 0.5 * (b - a)
+        f2 <- f(x2)
+      }
+    }
+    (a + b) / 2
+}
+
+mindistfromedge <- function (mask, traps, maxr=1e5, ntheta = 60, tol=0.0001) {
+    ## compare convex hulls
+    hull <- chull(traps)
+    trapshull <- traps[c(hull,hull[1]),]    ## ensure closed
+    hull <- chull(mask)
+    maskhull <- mask[c(hull,hull[1]),]
+    theta <- (2*pi) * (1:ntheta) / ntheta
+    inflate <- function (poly, r) {
+        r <- r-tol
+        ## add vertices; assumes theta
+        temp  <- data.frame(x = apply(expand.grid(poly$x, r * cos(theta)),1,sum),
+                   y = apply(expand.grid(poly$y, r * sin(theta)),1,sum))
+        hull <- chull(temp)
+        temp <- temp[c(hull,hull[1]), ]
+    }
+    fn <- function (x) {
+        all(insidepoly (inflate(trapshull, x), maskhull))
+    }
+    maskhull <- inflate(maskhull, attr(mask,'spacing')/2)
+    out <- bisect (fn,0,maxr,tol)
+    round(out, round(abs(log10(tol))))
 }
 
 mask.check <- function (object, buffers = NULL, spacings = NULL, poly = NULL,
@@ -22,7 +62,7 @@ mask.check <- function (object, buffers = NULL, spacings = NULL, poly = NULL,
     }
     refit <- inherits (object,'secr')
     if (!refit & !inherits(object,'capthist'))
-        stop ('require single-session capthist or secr object')
+        stop ("requires single-session 'capthist' or 'secr' object")
     MS <- ms(object)
     if (MS) {
         if (refit)
@@ -66,7 +106,7 @@ mask.check <- function (object, buffers = NULL, spacings = NULL, poly = NULL,
     else {
         if (refit) {
             if (!is.call(object$call))
-                stop('require fitted object from secr 1.5.0 or later')
+                stop("requires fitted object from secr 1.5.0 or later")
             trps <- traps(object$capthist)
             msk <- object$mask
             cpts <- object$capthist
@@ -110,9 +150,9 @@ mask.check <- function (object, buffers = NULL, spacings = NULL, poly = NULL,
         }
         else {
             if (is.null(buffers))
-                stop ('require buffers')
+                stop ("requires 'buffers'")
             if (is.null(spacings))
-                stop ('require spacings')
+                stop ("requires 'spacings'")
             cpts <- object
             if (MS) {
                 cpts <- cpts[[session]]
@@ -130,7 +170,7 @@ mask.check <- function (object, buffers = NULL, spacings = NULL, poly = NULL,
         if (LLonly) {
             defaultlink <- list(D='log', g0='logit', sigma='log', z='log', w='log', pID='logit',
                 beta0='identity', beta1='neglog', sdS='log', b0='log', b1='neglog', pmix='logit')
-            anycount <- detector(trps) %in% c('count', 'quadratbinary', 'quadratcount', 'polygon',
+            anycount <- detector(trps) %in% c('count', 'polygon',
                 'transect', 'times')
             if (is.null(newcall$details$scaleg0))
                 scaledg0 <- FALSE
@@ -139,7 +179,7 @@ mask.check <- function (object, buffers = NULL, spacings = NULL, poly = NULL,
             if (anycount | scaledg0) defaultlink$g0 <- 'log'
             newcall$link <- defaultlink
             if (is.null(realpar))
-                stop ('require either realpar or fitted model for LLonly')
+                stop ("'LLonly' requires either 'realpar' or fitted model")
             startbeta <- Xtransform(unlist(realpar), defaultlink, names(realpar))
             newcall <- replace(newcall, 'start', list(start=startbeta))
             if (refit) {
@@ -157,17 +197,18 @@ mask.check <- function (object, buffers = NULL, spacings = NULL, poly = NULL,
         }
         else {
             mask.check.output <- array(dim=c(nbuffer, 4, nspacing))
-            if (!is.null(file))
+            dimnames(mask.check.output) <- list(buffers, c('esa','LL','D-hat','se(D-hat)'),
+                spacings)
+            if (!is.null(file)) {
                 mask.check.fit <- vector(mode = 'list')
                 class(mask.check.fit) <- c('list','secrlist')
-                dimnames(mask.check.output) <- list(buffers, c('esa','LL','D-hat','se(D-hat)'),
-                                                    spacings)
+            }
             cat('Fitting models... \n')
         }
         if (!is.null(newcall$model))
             if (any(c('session','Session') %in% as.character(newcall$model)) |
                 !is.null(newcall$sessioncov)) {
-                stop('mask.check cannot handle models with session structure')
+                stop("mask.check cannot handle models with session structure")
             }
 
         flush.console()
@@ -217,8 +258,10 @@ mask.check <- function (object, buffers = NULL, spacings = NULL, poly = NULL,
         }
         if (!LLonly)
         {
-            if (nbuffer == 1)  mask.check.output <- t(mask.check.output[1,,]) ## drop first dim
-            if (nspacing == 1) mask.check.output <- mask.check.output[,,1]    ## drop third dim
+            if ((nbuffer == 1) & (nspacing>1))
+                mask.check.output <- t(mask.check.output[1,,]) ## drop first dim
+            else
+                if (nspacing == 1) mask.check.output <- mask.check.output[,,1]    ## drop third dim
         }
         mask.check.output
     }
