@@ -5,6 +5,7 @@
 ## 2009 11 04 signal strength
 ## 2010 07 01 alpha detectfn
 ## 2010 09 15 amend message for missing cutval
+## 2010 11 01 enabled plot detectfn=9
 ## default of limits changed to FALSE in plot.secr()
 ############################################################################################
 
@@ -68,14 +69,14 @@
     SS <- function (pars, r, cutval) {
         beta0 <- pars[1]; beta1 <- pars[2]; sdS <- pars[3]
         if (is.null(cutval))
-            stop ('require details$cutval for signal strength plot')
+            stop ("require 'details$cutval' for signal strength plot")
         mu <- beta0 + beta1 * r
         1 - pnorm (q=cutval, mean=mu, sd=sdS)
     }
     SSS <- function (pars, r, cutval) {
         beta0 <- pars[1]; beta1 <- pars[2]; sdS <- pars[3]
         if (is.null(cutval))
-            stop ('require details$cutval for signal strength plot')
+            stop ("require 'details$cutval' for signal strength plot")
         ## spherical so assume distance r measured from 1 m
         mu <- beta0 - 10 * log ( r^2 ) / 2.302585 + beta1 * (r-1)
         mu[r<1] <- beta0
@@ -114,24 +115,7 @@ plot.secr <- function (x, newdata=NULL, add = FALSE,
             out
         }
         else {
-
-            parnames <- switch (x$detectfn+1,
-                c('g0','sigma'),
-                c('g0','sigma','z'),
-                c('g0','sigma'),
-                c('g0','sigma','z'),
-                c('g0','sigma'),
-                c('g0','sigma','w'),
-                c('g0','sigma','w'),
-                c('g0','sigma','z'),
-                c('g0','sigma','z'),
-                c('b0','b1'),
-                c('beta0','beta1', 'sdS'),
-                c('beta0','beta1', 'sdS')
-            )
-
-            pars <- predicted[parnames,'estimate']
-
+            pars <- predicted[parnames(x$detectfn),'estimate']
             pars[is.na(pars)] <- unlist(x$fixed)
             dfn <- switch (x$detectfn+1, HN, HZ, EX, CHN, UN, WEX, ANN, CLN, CG, BSS, SS, SSS)
             if (sigmatick) {
@@ -234,7 +218,7 @@ plot.secr <- function (x, newdata=NULL, add = FALSE,
     z <- abs(qnorm(1-alpha/2))   ## beware confusion with hazard-rate z!
     temp <- predict (x, newdata)
     if (is.null(ylim)) {
-        if (x$detectfn %in% c(10,11)) {
+        if (x$detectfn %in% c(9,10,11)) {      ## included 9 2010-11-01
             ylim <- c(0, 1)
         }
         else {
@@ -259,8 +243,10 @@ plot.secr <- function (x, newdata=NULL, add = FALSE,
             xlab <- 'Distance  (m)'
         if (is.null(ylab)) {
            binomN <- ifelse(is.null(x$details$binomN),0,x$details$binomN)
-           dlambda <- (detector(traps(x$capthist)) %in% c('quadratbinary', 'polygon')) |
-               ((detector(traps(x$capthist)) %in% c('count','quadratcount')) & (binomN==0))
+##           dlambda <- (detector(traps(x$capthist)) %in% c('quadratbinary', 'polygon')) |
+##               ((detector(traps(x$capthist)) %in% c('count','quadratcount')) & (binomN==0))
+           dlambda <- (detector(traps(x$capthist)) %in% c('polygon')) |
+               ((detector(traps(x$capthist)) %in% c('count')) & (binomN==0))
            if (dlambda)
                ylab <- 'Detection lambda'
            else
@@ -302,6 +288,13 @@ detectfnplot <- function (detectfn, pars, details = NULL,
 
     ### mainline
 
+    if (is.list(pars)) {   ## 2010-10-26
+        if (is.list(pars[[1]]))
+            pars <- matrix(unlist(pars), nr = length(pars), byrow = T)
+        else
+            pars <- unlist(pars)
+    }
+
     if (!is.matrix(pars)) pars <- matrix(pars, nr=1)
 
     ## added 2010-07-01
@@ -311,8 +304,8 @@ detectfnplot <- function (detectfn, pars, details = NULL,
     needp <- c(2,3,2,3,2,3,3,3,3,2,3,3)[detectfn+1]
 
     if (ncol(pars) != needp)
-        stop(paste('require', needp, 'parameters for', detectionfunctionname(detectfn),
-                   'detection function'))
+        stop(paste("require", needp, "parameters for", detectionfunctionname(detectfn),
+                   "detection function"))
 
     if (is.null(ylim)) {
         if (detectfn %in% c(10,11)) {
@@ -359,6 +352,12 @@ attenuationplot <- function (pars, add = FALSE, spherical = TRUE,
         data.frame(x=xval, y=y)
     }
 
+    if (is.list(pars)) {   ## 2010-10-26
+        if (is.list(pars[[1]]))
+            pars <- matrix(unlist(pars), nr = length(pars), byrow = T)
+        else
+            pars <- unlist(pars)
+    }
     if (!is.matrix(pars)) pars <- matrix(pars, nr=1)
 
     if (is.null(ylim)) {
