@@ -11,7 +11,7 @@ write.traps <- function (object, file='', ..., deblank = TRUE, header = TRUE, nd
         header, deparse(substitute(object), control=NULL))
     header <- ifelse (is.character(header), TRUE, header)
 
-    if (!is(object, 'traps')) stop ('write.traps requires a traps object')
+    if (!is(object, 'traps')) stop ("requires a 'traps' object")
     n <- nrow(object)
     object$x <- round(object$x,ndec)
     object$y <- round(object$y,ndec)
@@ -48,4 +48,3 @@ write.traps <- function (object, file='', ..., deblank = TRUE, header = TRUE, nd
 
 }
 ############################################################################################
-
